@@ -1,6 +1,6 @@
 rj() {
     search_phrase=$1
-    best_match=$(rustjump -s $search_phrase)
+    best_match=$(rust-autojump -s $search_phrase)
 
     if [ $status -eq 0 ]
     then
@@ -11,7 +11,7 @@ rj() {
 }
 
 rust_jump_chpwd() {
-    rustjump --add "$(pwd)" >/dev/null &!
+    rust-autojump --add "$(pwd)" >/dev/null &!
 }
 
 typeset -gaU chpwd_functions
